QUADS Project Code of Conduct
=============================

## Overview
We have a simple code of conduct derived from [George Carlin's](https://en.wikipedia.org/wiki/George_Carlin) character Rufus from [Bill and Ted's Excellent Adventure](https://en.wikipedia.org/wiki/Bill_%26_Ted%27s_Excellent_Adventure).

### Guidelines

#### Be Excellent to Each Other, and Party On.
* Always assume good intent in others.
* Focus on positivity and improvement.
* Don't forget to have fun.

#### Don't be Bogus.
* Act in a courteous manner towards everyone.
* Don't totally ravage Oshman’s Sporting Goods.
